%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%chirp_lineal.m%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%
%%%%Description: This function generates a overall linear chirp pulse. 
%%%%INPUTS:
%%%%f0 is the central frequency of the pulse.
%%%%dt ratio (duty cicle)/(signal period).
%%%%Af is the maximun frequency excursion.
%%%%Np number of pulse replications.
%%%%prf is 1/(signal period).
%%%%fs sample frequency.
%%%%OUTPUTS:
%%%%s2 is the chirp pulse.
%%%%t is the time axis.
%%%%f is the frequency axis.
function [s2,t,f]=chirp_lineal(f0,dt,Af,Np,prf,fs)
%Constants and parameters
Ts=1/fs;
T=1/prf;
tau=dt*T;
Nm=ceil(T*fs);
N=Nm*Np;
%Simple pulse
tp=linspace(0,tau,ceil(Nm*dt));
mu=2*pi*Af/tau;
% wi=2*pi*(f0+mu*tp-mu*tp(round(end/2)));
%  figure(),
%  plot(tp,wi/(2*pi*1e6),'k'),title ('Instantaneous frequency');
%  xlabel('Time'), ylabel('fi(t) [Mhz]'), grid on;
% s1=sin(wi.*tp); 
s1=sin(2*pi*f0*tp+mu*tp.^2/2);
s1=[s1 zeros(1,floor((1-dt)*Nm))] ; 
%Pulse replications and axis generation
s2=repmat(s1,1,Np);
t=linspace(0,Np*T,N);
f=linspace(-0.5/Ts,0.5/Ts,N);
end
